@@ -61,7 +61,7 @@ print.summary.meta <- function(x,
   ##
   bip <- inherits(x, c("metabin", "metainc", "metaprop"))
   ##
-  prediction <- prediction & comb.random & k>=3
+  prediction <- prediction & k>=3
   ##
   if (is.null(x$df.Q))
     df.Q <- k-1
@@ -240,13 +240,14 @@ print.summary.meta <- function(x,
             metacont=inherits(x, "metacont"),
             pooledvar=x$pooledvar,
             method.smd=x$method.smd,
-            sd.glass=x$sd.glass)
+            sd.glass=x$sd.glass,
+            exact.smd=x$exact.smd)
   }
   else{
     ##
     ## Print results for meta-analysis with more than one study
     ##
-    if (comb.fixed|comb.random){
+    if (comb.fixed|comb.random|prediction){
       if (!inherits(x, "trimfill"))
         cat(paste("Number of studies combined: k=", k, "\n\n", sep=""))
       else
@@ -459,7 +460,8 @@ print.summary.meta <- function(x,
             metacont=inherits(x, "metacont"),
             pooledvar=x$pooledvar,
             method.smd=x$method.smd,
-            sd.glass=x$sd.glass)
+            sd.glass=x$sd.glass,
+            exact.smd=x$exact.smd)
   }
   
   
